# -*- coding: utf-8 -*-
"""
KM3NeT Data Definitions v2.1.0-1-ga85a9c1
https://git.km3net.de/common/km3net-dataformat
"""

# fitparameters
data = dict(
    JGANDALF_BETA0_RAD=0,
    JGANDALF_BETA1_RAD=1,
    JGANDALF_CHI2=2,
    JGANDALF_NUMBER_OF_HITS=3,
    JENERGY_ENERGY=4,
    JENERGY_CHI2=5,
    JGANDALF_LAMBDA=6,
    JGANDALF_NUMBER_OF_ITERATIONS=7,
    JSTART_NPE_MIP=8,
    JSTART_NPE_MIP_TOTAL=9,
    JSTART_LENGTH_METRES=10,
    JVETO_NPE=11,
    JVETO_NUMBER_OF_HITS=12,
    JENERGY_MUON_RANGE_METRES=13,
    JENERGY_NOISE_LIKELIHOOD=14,
    JENERGY_NDF=15,
    JENERGY_NUMBER_OF_HITS=16,
    JCOPY_Z_M=17,
    JPP_COVERAGE_ORIENTATION=18,
    JPP_COVERAGE_POSITION=19,
    JENERGY_MINIMAL_ENERGY=20,
    JENERGY_MAXIMAL_ENERGY=21,
    JSHOWERFIT_ENERGY=4,
    AASHOWERFIT_ENERGY=0,
    AASHOWERFIT_NUMBER_OF_HITS=1,
)



# -*- coding: utf-8 -*-
"""
KM3NeT Data Definitions v2.1.0-1-ga85a9c1
https://git.km3net.de/common/km3net-dataformat
"""

# w2list_gseagen
data = dict(
    W2LIST_GSEAGEN_PS=0,
    W2LIST_GSEAGEN_EG=1,
    W2LIST_GSEAGEN_XSEC_MEAN=2,
    W2LIST_GSEAGEN_COLUMN_DEPTH=3,
    W2LIST_GSEAGEN_P_EARTH=4,
    W2LIST_GSEAGEN_WATER_INT_LEN=5,
    W2LIST_GSEAGEN_P_SCALE=6,
    W2LIST_GSEAGEN_BX=7,
    W2LIST_GSEAGEN_BY=8,
    W2LIST_GSEAGEN_ICHAN=9,
    W2LIST_GSEAGEN_CC=10,
    W2LIST_GSEAGEN_DISTAMAX=11,
    W2LIST_GSEAGEN_WATERXSEC=12,
    W2LIST_GSEAGEN_XSEC=13,
    W2LIST_GSEAGEN_DXSEC=14,
    W2LIST_GSEAGEN_TARGETA=15,
    W2LIST_GSEAGEN_TARGETZ=16,
    W2LIST_GSEAGEN_VERINCAN=17,
    W2LIST_GSEAGEN_LEPINCAN=18,
    W2LIST_GSEAGEN_N_RETRIES=19,
    W2LIST_GSEAGEN_CUSTOM_YAW=20,
    W2LIST_GSEAGEN_CUSTOM_PITCH=21,
    W2LIST_GSEAGEN_CUSTOM_ROLL=22,
)



# -*- coding: utf-8 -*-
"""
KM3NeT Data Definitions v2.1.0-1-ga85a9c1
https://git.km3net.de/common/km3net-dataformat
"""

# pmt_status
data = dict(
    PMT_DISABLE= 0,
    HIGH_RATE_VETO_DISABLE= 1,
    FIFO_FULL_DISABLE= 2,
    UDP_COUNTER_DISABLE= 3,
    UDP_TRAILER_DISABLE= 4,
    OUT_OF_SYNC= 5,
)



#!/usr/bin/env python3
import unittest
import tempfile

import numpy as np
from km3net_testdata import data_path

from km3io.acoustics import RawAcousticReader


class TestRawAcousticReader(unittest.TestCase):
    def setUp(self):
        self.r = RawAcousticReader(
            data_path("acoustics/DOM_808956920_CH1_1608751683.bin")
        )

    def test_id(self):
        assert "808956920" == self.r.id

    def test_timestamps(self):
        assert np.allclose(
            [[1608751679, 1608751680], [47216000, 24159200]], self.r.timestamps
        )

    def test_pcm(self):
        assert np.allclose([0.00315881, 0.00326228, 0.00348866], self.r.pcm[:3])

    def test_timebase(self):
        assert 246520 == len(self.r.timebase)
        print(self.r.timebase[:3])
        assert np.allclose(
            [1.60875168e09, 1.60875168e09, 1.60875168e09], list(self.r.timebase[:3])
        )

    def test_to_wav(self):
        outfile = tempfile.NamedTemporaryFile(delete=True)
        self.r.to_wav(outfile)
